

#include <ICBRevamperPluginItem.h>


class CBRevamperSamplePluginItem : public ICBRevamperPluginItem {
public:
	virtual HRESULT cbrQueryInsterface(LPCWSTR pName, void** ppv) 
	{
		return E_NOINTERFACE;
	}

	// UUID of this item, must be unique
	virtual HRESULT GetUUID(UUID* pUUID) {
		static UUID sUUID = { /* 23005e42-886e-4254-821a-6b36d2ea5e78 */
			0x23005e42,
			0x886e,
			0x4254,
			{0x82, 0x1a, 0x6b, 0x36, 0xd2, 0xea, 0x5e, 0x78}
		  };

		*pUUID = sUUID;
		return S_OK;
	}
	
	// Title of this item
	// pLang : User lang setting, this value can be "ENU", "JPN", or other language.
	// pTitle : Output, use SysAllocString to allocate BSTR.
	// This value is used in Menu Text or Dialog Title and so on.
	virtual HRESULT GetTitle(LPCWSTR pLang, BSTR* pTitle) 
	{
		*pTitle = SysAllocString(L"Count characters");
		return S_OK;
	}

	// Explanation of this item in one line
	virtual HRESULT GetOnelineDescription(LPCWSTR pLang, BSTR* pDesc) 
	{
		return GetTitle(pLang,pDesc);
	}

	// Displayed in the column of listview item.
	// This function is called when this item has user data.
	// nLevel : 1=column aux2, 2=column aux3, ...
	virtual HRESULT GetDisplayText(LPCWSTR pLang, int nLevel, BSTR pUserData, BSTR* pText) 
	{
		if(nLevel != 1)
			return E_NOTIMPL;

		return GetTitle(pLang, pText);
	}

	// If this item has user data, it returns TRUE.
	// When this function returns TRUE, "Plugin Option" button shows in item dialog.
	virtual HRESULT HasUserSettings(BOOL* pb) 
	{
		*pb = FALSE;
		return S_OK;
	}

	// If user pressed "Plugin Option" in the Item dialog, this function will be called
	// pUserDataIn : User data this plugin previously assigned.
	// PUserDataOut : UserData to set, this value will be serialized and persistant,
	//   Use SysAlloc... func to allocate, these functions can allocate and assign byte data.
	virtual HRESULT ShowDialog(LPCWSTR pLang, HWND hWnd, BOOL* pbCancel, BSTR pUserDataIn, BSTR* pUserDataOut) 
	{
		return E_NOTIMPL;
	}

	// Called when clipboard revamping is neccesary,
	virtual HRESULT DoRevamp(LPCWSTR pIN, BSTR* pbOut, BSTR pUserData);
};



class CBRevamperSamplePlugin : public ICBRevamperPlugin {
public:
	virtual HRESULT cbrQueryInsterface(LPCWSTR pName, void** ppv) 
	{
		return E_NOINTERFACE;
	}

	// Title of this plugin
	virtual HRESULT GetTitle(LPCWSTR pLang, BSTR* pbTitle) 
	{
		*pbTitle = SysAllocString(L"Sample Plugin");
		return S_OK;
	}
	
	// Description of this plugin
	virtual HRESULT GetPluginDescription(BSTR pLang, BSTR* pbDesc) 
	{
		*pbDesc = SysAllocString(L"Count characters");
		return S_OK;
	}
	
	// Return item of this plugin implements.
	// This function is called with index starting from 0 until error returned.
	// For example, if this plugin has two items, it must return error(E_FAIL, E_NOINTERFACE..) 
	// at index is 2.
	virtual HRESULT EnumItems(UINT index, ICBRevamperPluginItem** ppItem);
};